@@ -14,7 +14,7 @@ nsrr_website = function() {
 #' @rdname nsrr_website
 nsrr_api_url = function() {
   website = nsrr_website()
-  url = paste0(website, "/api/v1")
+  url = paste0(website, "/api/", nsrr_api_version())
   url
 }
 
