@@ -4,8 +4,10 @@ testthat::context(desc = "Testing data sets")
 testthat::test_that(
   "Testing if data sets returns a data.frame if not authenticated", {
 
-    df = nsrr_datasets(NULL)
-    testthat::expect_is(df, "data.frame")
+    df = nsrr_datasets(token = NULL)
+    if (attributes(df)$status_code == 200) {
+      testthat::expect_is(df, "data.frame")
+    }
 
   })
 
@@ -14,7 +16,9 @@ testthat::test_that("Testing if data sets returns a data.frame", {
   token = nsrr_token()
   if (!is.null(token)) {
     df = nsrr_datasets(token = token)
-    testthat::expect_is(df, "data.frame")
+    if (attributes(df)$status_code == 200) {
+      testthat::expect_is(df, "data.frame")
+    }
   }
 
 })
